#
# spec file for package purple-lurch
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   lurch
Name:           purple-lurch
Version:        0.7.0
Release:        1.14
Summary:        OMEMO for libpurple
License:        GPL-3.0-only
URL:            https://github.com/gkdr/lurch
Source:         %{_name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libgcrypt-devel
BuildRequires:  libpurple
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mxml)
BuildRequires:  pkgconfig(purple)
BuildRequires:  pkgconfig(sqlite3)

%description
This plugin brings Double Ratchet to libpurple applications such as
Pidgin by implementing OMEMO.

%package -n libpurple-plugin-%{_name}
Summary:        OMEMO for libpurple
Recommends:     libpurple-plugin-carbons
Enhances:       libpurple

%description -n libpurple-plugin-%{_name}
This plugin brings Double Ratchet to libpurple applications such as
Pidgin by implementing OMEMO.

%prep
%setup -q -n %{_name}-%{version}

%build
export CFLAGS='%{optflags}'
%make_build

%install
%make_install

%files -n libpurple-plugin-%{_name}
%license LICENSE
%doc README.md
%{_libdir}/purple-2/%{_name}.so

%changelog
* Sat Feb 13 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.7.0:
  * An API reachable through libpurple signals.
    See lurch_api.h for details and usage.
  * Testing setup using cmocka and tests for new modules.
  * The possibility to dynamically link against the submodule
    libaries.
  * Change the /command handler using the API.
    The commands are a bit different and some are new.
  * Warnings are no longer displayed at level "error".
  * Report skipped messages in conversation window and not just in
    the debug log.
  * Some memory handling improvements.
  * Update the libomemo submodule to version 0.7.1.
  * Update the axc submodule to version 0.3.4.
- Remove purple-lurch-libomemo-fix-dino-compat.patch,
  libomemo-27.patch: fixed upstream.
* Sun Nov 29 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add libomemo-27.patch to fix encryption
* Mon Sep 16 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Add purple-lurch-libomemo-fix-dino-compat.patch: Fix
  compatibility issues with Dino (commit e3b2125e).
* Sun Dec 30 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.6.8:
  * Makefile adaptations should help building and running this for
    some.
  * Fix some bugs regarding carbons and sending messages to
    yourself, also added NULL checks so that it plays nicer with
    other plugins which might set the message to NULL.
  * Update submodules and their dependencies, most importantly
    libsignal-protocol-c to 2.3.2.
  * Add plugin preferences prototype: Single option is logging
    verbosity on the debug log.
* Tue May  8 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.6.7:
  * Fix not freeing account list after plugin load.
  * Ignore OMEMO messsage in MUCs if sender is not present.
  * Revert to EME instead of additional body.
  * Remove the magic number for proper enum.
  * Set the correct conversation type when decrypting incoming own
    message to others.
  * Decrypt messages from own account in MUCs.
  * Fix but also disable axc log output.
  * The MUC handling has been rewritten.
  * Destroy the message after exporting.
  * Add some debug output.
* Thu Mar 15 2018 sor.alexei@meowr.ru
- Update to version 0.6.6:
  * Skip adding recipient's devices if addressed to oneself.
  * Fix not initialising a pointer to NULL.
  * Allow to override all *FLAGS.
  * Allow to build a static library.
  * Report AXC errors through purple_debug.
  * Update submodules to current versions.
  * Fix warnings.
  * Some clean up.
- Remove the libjabber.so discoverability workaround: not needed
  anymore.
- Remove the rpmlintrc file: not really needed.
- Add CPPFLAGS
* Thu Apr  6 2017 9@cirno.systems
- 0.6.5
  * strips <html> tags to prevent message leakage
  * authentication tag is now appended to the key, i.e. is part
    of the data which is encrypted with the double ratchet session
  * changes message handler priorities so that this plugin is one
    of the last to process them, and thus fixes the incompatibility
    with the XMPP Receipts plugin
  * fixes display of (OMEMO) when switching from non-OMEMO
    conversations
* Fri Mar 31 2017 9@cirno.systems
- Initial commit, 0.6.4
